#! /bin/bash
#
# Skeleton for shell(bash) script.
# Copyright (C) 2005 MiKael NAVARRO
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

PROGNAME=`basename ${0}`
VERSION="20111111"

# Hack prevention
PATH="/sbin:/usr/sbin:/bin:/usr/bin"

# Error codes
WRONG_PARAMS=5
INTERRUPTED=99
DEFAULT_ERROR=1


#
# Signal recieved => end.
#
# $1= message
# $2= exit status
#
end() {
    echo "${1}! Doing cleanup before ending...."
    exit ${2};
}

#
# Print sript help.
#
usage() {
    cat <<EOF
$1 [-a|--a-long] [-b|--b-long <barg>] [-c|--c-long]
Skeleton for shell(bash) script.

Example input and output (from the bash prompt):
  $1 -a par1 'another arg' --c-long 'wow!*\?' -cmore -b " very long "
  Option a
  Option c, argument 'wow!*\?'
  Option c, argument 'more'
  Option b, argument ' very long '
  Remaining arguments:
  --> 'par1'
  --> 'another arg'
EOF
}

# Define function to call when SIGTERM is recieved
trap "end 'Interruped' $INTERRUPTED" 1 2 3 15


#
# A small example program for using the new getopt(1) program.
# This program will only work with bash(1)
#

# Note that we use `"$@"' to let each command-line parameter expand to a 
# separate word. The quotes around `$@' are essential!
# We need OPTS as the `eval set --' would nuke the return value of getopt.
SHORTOPTS="ab:c:vdhV"
LONGOPTS="a-long,b-long:,c-long:,verbose,debug,help,version"
OPTS=`getopt -o $SHORTOPTS --long $LONGOPTS -n $PROGNAME -- "$@"`

if [ $? != 0 ] ; then echo "Terminating..." >&2 ; exit $WRONG_PARAMS ; fi

# Note the quotes around `$OPTS': they are essential!
eval set -- "$OPTS"

while true ; do
    case "$1" in
        -h|--help) usage ${0} ; exit 0 ;;
        -v|--verbose) set -v ; shift ;;
        -d|--debug) set -x ; shift ;;
        -V|--verson) echo "${PROGNAME} v${VERSION}" ; exit 0 ;;

	-a|--a-long) echo "Option a" ; shift ;;
	-b|--b-long) echo "Option b, argument '$2'" ; shift 2 ;;
	-c|--c-long) 
			# c has an optional argument. As we are in quoted mode,
			# an empty parameter will be generated if its optional
			# argument is not found.
	    case "$2" in
		"") echo "Option c, no argument"; shift 2 ;;
		*)  echo "Option c, argument '$2'" ; shift 2 ;;
	    esac ;;

	--) shift ; break ;;
	*) echo "Internal error!" ; exit $WRONG_PARAMS ;;
    esac
done
echo "Remaining arguments:"
for arg do echo '--> '"\`$arg'" ; done


# 
# Main
#

while true
do
    # Doing something usefull
    echo "Sleep five seconds"
    sleep 5
done

exit 0
