#! /bin/ksh
#
# Skeleton for shell(ksh) script.
# Copyright (C) 2005 MiKael NAVARRO
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

#
# Function given to trap built in command.
#
trapsignal() {
    echo "Signal received. Doing cleanup before ending...."
    exit 1;
}

#
# Print script usage.
# 
usage() {
    echo "`basename $1` -b <barg> [-a] "
    echo "Skeleton for shell(ksh) script."
    echo ""
    echo "Ex: `basename $1` -b barg"
    echo ""
    echo "  -b <barg>  option b"
    echo ""
    echo "  -a         option a"
    echo "  -v         verbose mode"
    echo "  -d         debug mode"
    echo "  -h         this help"
    echo "  -V         print script version"
    echo ""
    echo "Return values :"
    echo "  0 => OK"
    echo "  1 => KO"
    echo "  2 => error in arguments"
}

# Trapping signals INT TERM
trap trapsignal INT TERM


# 
# Option parsing
# 
ARGERROR=0
ARGA_O=""
ARGB_O=""

# Script with no option => print usage and exit
if [ $# -eq 0 ]
then
    usage ${0}
    exit 2
fi

while getopts :dVvhab: opt
  do
  case ${opt} in
      h) usage ${0};exit 0;;
      d) set -x;;
      v) set -v;;
      V) echo "${0} 2005/07/01";exit 0;;
      a) ARGA_O=1;; 
      b) ARGB_O=${OPTARG};; 
      \?) echo "Unknown option: ${OPTARG}";ARGERROR=1;; 
  esac
done
shift `expr $OPTIND - 1`

if [ ${ARGERROR} != 0 ]
then
    echo "Error(s) in option parsing. Aborting!"
    exit 2
fi

if [ $# -ne 0 ]
then
    echo "Error: extra arguments '${@}'"
    exit 2
fi

if [ -z "${ARGA_O}" ]
then
    echo "Option '-a' is not set"
else 
    echo "Option '-a' is set"
fi

# Compulsory arguments
if [ -z "${ARGB_O}" ]
then
    echo "Error, option '-b <argb>' is compulsory"
    exit 2
else 
    echo "Option '-b' is set with value '${ARGB_O}'"
fi


# 
# Main
#

while true
do
    # Doing something usefull
    echo "Sleep five seconds"
    sleep 5
done

exit 0
