#!/bin/zsh -f
#
# Skeleton for shell(zsh) script.
# Copyright (C) 2005 MiKael NAVARRO
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

#
# Trap signal SIGINT
#
# TRAP<NAL>
#     If defined and non-null, this function will be executed whenever 
#     the shell catches a signal SIG<NAL>, where <NAL> is a signal name as specified 
#     for the kill builtin. The signal number will be passed as the first parameter 
#     to the function.
#
#     If a function of this form is defined and null, the shell and processes 
#     spawned by it will ignore SIG<NAL>. 
# 
TRAPINT() {
    echo "SIGINT (number is $1) received. Doing cleanup before ending...."
    exit 1;
}

#
# Print script usage
# 
usage() {
    cat <<EOF
$1 [-a|--aopt] [-b|--bopt <barg>] [-c|--copt]
Skeleton for shell(zsh) script.

Example input and output (from the z-shell prompt):
  $1 -a par1 'another arg' --copt 'wow!*\?' -cmore -b " very long "
  Option a
  Option c, argument 'wow!*\?'
  Option c, argument 'more'
  Option b, argument ' very long '
  non option arguments are: 'part1 another arg'
EOF
}


# 
# Option parsing
# 
zparseopts -D -E -A Args -- a -aopt b: -bopt: c: -copt: v d h V

if (( $? != 0 || ${+Args[-h]} )); then
    usage ${0}
    exit 1
fi
if (( ${+Args[-v]} )); then
    set -v
fi
if (( ${+Args[-d]} )); then
    set -x
fi
if (( ${+Args[-V]} )); then
    print "`basename ${0}` v20160330"
    exit 0
fi

if (( ${+Args[-a]} || ${+Args[--aopt]} )); then
    print "Option a"
fi
if (( ${+Args[--copt]} )); then
    print "Option c, argument '$Args[--copt]'"
fi
if (( ${+Args[-c]} )); then
    print "Option c, argument '$Args[-c]'"
fi
if (( ${+Args[-b]} || ${+Args[--bopt]} )); then
    print "Option b, argument '$Args[-b]'"
fi
if [ "$#@" -gt 0 ]; then
    print "Non option arguments are: '$@'"
fi
# ...


# 
# Main
#

while true
do
    # Doing something usefull
    echo "Sleep five seconds"
    sleep 5
done

exit 0
